//CFTTFileSystem_APKX - [2020-04-13 11:57:46]
#ifndef _CFTTFILESYSTEM_APKX_H_
#define _CFTTFILESYSTEM_APKX_H_

#include "CFTTFileSystem_PAK.h"
#include "CFTTFile_AndroidMemMap.h"


/*
0026C5A0 CFTTFileSystem_APKX::CFTTFileSystem_APKX(char const*)
0026CE7C CFTTFileSystem_APKX::~CFTTFileSystem_APKX()
0026CEA4 CFTTFileSystem_APKX::~CFTTFileSystem_APKX()

; `vtable for'CFTTFileSystem_APKX
vptr_CFTTFileSystem_APKX_329B88
  CFTTFileSystem_APKX::~CFTTFileSystem_APKX()
  CFTTFileSystem_APKX::~CFTTFileSystem_APKX()
  CFTTFileSystem::GetAbsoluteFilename(char const*,char *,uint)
  CFTTFileSystem_PAK::Open(char const*,uint,EFTTMemHeapID)
  CFTTFileSystem::Delete(char const*)
  CFTTFileSystem::Rename(char const*,char const*,CFTTFileSystem*)
  CFTTFileSystem::Copy(char const*,char const*,bool)
  CFTTFileSystem_PAK::OpenDir(char const*,CFTTFileIterator **)
  CFTTFileSystem_PAK::FileExistsFS(char const*)
  CFTTFileSystem_PAK::GetAttributesFS(char const*,TFTTFileAttributes *)
*/

class CFTTFileSystem_APKX : public CFTTFileSystem_PAK {
 public:
  CFTTFileSystem_APKX(const char* filepath);  //0026C5A0
  virtual ~CFTTFileSystem_APKX();             //0026CE7C 0026CEA4

  CFTTFile_AndroidMemMap* m_file_map;
};

#endif  //_CFTTFILESYSTEM_APKX_H_